package com.ruoyi.common.core.domain.entity;

import com.easy.mongodb.common.annotation.JoinCondition;
import com.easy.mongodb.common.annotation.Table;
import com.easy.mongodb.common.annotation.TableField;
import com.easy.mongodb.common.enums.FieldType;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;
import java.util.List;
import java.util.Objects;

/**
 * 角色表 sys_role
 *
 * @author ruoyi
 */
@Table(value = "sys_role")
public class SysRole extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /** 角色ID */
//    @Excel(name = "角色序号", cellType = ColumnType.NUMERIC)
//    private Long roleId;

    /** 角色名称 */
    @Excel(name = "角色名称")
    private String roleName;

    /** 角色权限 */
    @Excel(name = "角色权限")
    private String roleKey;

    /** 角色排序 */
    @Excel(name = "角色排序")
    private String roleSort;

    /** 数据范围（1：所有数据权限；2：自定义数据权限；3：本部门数据权限；4：本部门及以下数据权限；5：仅本人数据权限） */
    @Excel(name = "数据范围", readConverterExp = "1=所有数据权限,2=自定义数据权限,3=本部门数据权限,4=本部门及以下数据权限,5=仅本人数据权限")
    private String dataScope;

    /** 菜单树选择项是否关联显示（ 0：父子不互相关联显示 1：父子互相关联显示） */
    private Boolean menuCheckStrictly;

    /** 部门树选择项是否关联显示（0：父子不互相关联显示 1：父子互相关联显示 ） */
    private Boolean deptCheckStrictly;

    /** 角色状态（0正常 1停用） */
    @Excel(name = "角色状态", readConverterExp = "0=正常,1=停用")
    private String status;

    /** 删除标志（0代表存在 2代表删除） */
    private String delFlag;

    /** 用户是否存在此角色标识 默认不存在 */
    @TableField(exist = false)
    private Boolean flag = false;

    /** 菜单组 */
    @TableField(
            fieldType = FieldType.JOIN,
            condition = @JoinCondition(
                    entity = SysMenu.class, field = "_id",
                    midEntity = SysRoleMenu.class, selfField = "_id", selfMidField = "role_id", joinMidField = "menu_id", joinField = "_id"
            ))
    private List<String> menuIds;

    /** 部门组（数据权限） */
    @TableField(
            fieldType = FieldType.JOIN,
            condition = @JoinCondition(
                    entity = SysDept.class, field = "_id",
                    midEntity = SysRoleDept.class, selfField = "_id", selfMidField = "role_id", joinMidField = "dept_id", joinField = "_id"
            ))
    private List<String> deptIds;

    private Boolean admin;

    public SysRole() {

    }

    public SysRole(String roleId) {
        this.setId(roleId);
    }

    public Boolean getAdmin() {
        return this.admin;
    }

    public void setAdmin(Boolean admin) {
        this.admin = admin;
    }

    public boolean isAdmin() {
        return Objects.isNull(this.admin) ? false : this.admin;
    }


    @NotBlank(message = "角色名称不能为空")
    @Size(min = 0, max = 30, message = "角色名称长度不能超过30个字符")
    public String getRoleName() {
        return this.roleName;
    }

    public void setRoleName(String roleName) {
        this.roleName = roleName;
    }

    @NotBlank(message = "权限字符不能为空")
    @Size(min = 0, max = 100, message = "权限字符长度不能超过100个字符")
    public String getRoleKey() {
        return this.roleKey;
    }

    public void setRoleKey(String roleKey) {
        this.roleKey = roleKey;
    }

    @NotBlank(message = "显示顺序不能为空")
    public String getRoleSort() {
        return this.roleSort;
    }

    public void setRoleSort(String roleSort) {
        this.roleSort = roleSort;
    }

    public String getDataScope() {
        return this.dataScope;
    }

    public void setDataScope(String dataScope) {
        this.dataScope = dataScope;
    }

    public boolean isMenuCheckStrictly() {
        return this.menuCheckStrictly;
    }

    public void setMenuCheckStrictly(boolean menuCheckStrictly) {
        this.menuCheckStrictly = menuCheckStrictly;
    }

    public boolean isDeptCheckStrictly() {
        return this.deptCheckStrictly;
    }

    public void setDeptCheckStrictly(boolean deptCheckStrictly) {
        this.deptCheckStrictly = deptCheckStrictly;
    }

    public String getStatus() {
        return this.status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getDelFlag() {
        return this.delFlag;
    }

    public void setDelFlag(String delFlag) {
        this.delFlag = delFlag;
    }

    public boolean isFlag() {
        return this.flag;
    }

    public void setFlag(boolean flag) {
        this.flag = flag;
    }

    public List<String> getMenuIds() {
        return this.menuIds;
    }

    public void setMenuIds(List<String> menuIds) {
        this.menuIds = menuIds;
    }

    public List<String> getDeptIds() {
        return this.deptIds;
    }

    public void setDeptIds(List<String> deptIds) {
        this.deptIds = deptIds;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("roleId", this.getId())
                .append("roleName", this.getRoleName())
                .append("roleKey", this.getRoleKey())
                .append("roleSort", this.getRoleSort())
                .append("dataScope", this.getDataScope())
                .append("menuCheckStrictly", this.isMenuCheckStrictly())
                .append("deptCheckStrictly", this.isDeptCheckStrictly())
                .append("status", this.getStatus())
                .append("delFlag", this.getDelFlag())
                .append("createBy", this.getCreateBy())
                .append("createTime", this.getCreateTime())
                .append("updateBy", this.getUpdateBy())
                .append("updateTime", this.getUpdateTime())
                .append("remark", this.getRemark())
                .toString();
    }
}
