package com.ruoyi.common.core.service.impl;

import com.easy.mongodb.core.toolkit.Wraps;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.mapper.SysDictDataMapper;
import com.ruoyi.common.core.service.ISysDictDataService;
import com.ruoyi.common.utils.DictUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 字典 业务层处理
 *
 * @author ruoyi
 */
@Service
public class SysDictDataServiceImpl implements ISysDictDataService {
    @Autowired
    private SysDictDataMapper dictDataMapper;

    /**
     * 根据条件分页查询字典数据
     *
     * @param dictData 字典数据信息
     * @return 字典数据集合信息
     */
    @Override
    public List<SysDictData> selectDictDataList(SysDictData dictData) {
//        return this.dictDataMapper.selectDictDataList(dictData);
        return this.dictDataMapper.selectList(dictData);
    }

    /**
     * 根据字典类型和字典键值查询字典数据信息
     *
     * @param dictType  字典类型
     * @param dictValue 字典键值
     * @return 字典标签
     */
    @Override
    public String selectDictLabel(String dictType, String dictValue) {
        return this.dictDataMapper.selectOne(Wraps.<SysDictData>lbQ(SysDictData.class).eq(SysDictData::getDictType, dictType).eq(SysDictData::getDictValue, dictValue)).getDictLabel();
    }

    /**
     * 根据字典数据ID查询信息
     *
     * @param dictCode 字典数据ID
     * @return 字典数据
     */
    @Override
    public SysDictData selectDictDataById(String dictCode) {
        return this.dictDataMapper.selectOne(Wraps.<SysDictData>lbQ(SysDictData.class).eq(SysDictData::getDictCode, dictCode));
    }

    /**
     * 批量删除字典数据信息
     *
     * @param dictCodes 需要删除的字典数据ID
     */
    @Override
    public void deleteDictDataByIds(String[] dictCodes) {
        for (String dictCode : dictCodes) {
            SysDictData data = this.selectDictDataById(dictCode);
            this.dictDataMapper.delete(Wraps.<SysDictData>lbQ(SysDictData.class).eq(SysDictData::getDictCode, dictCode));
            List<SysDictData> dictDatas = this.dictDataMapper.selectList(Wraps.<SysDictData>lbQ().eq(SysDictData::getDictType, data.getDictType()));
            DictUtils.setDictCache(data.getDictType(), dictDatas);
        }
    }

    /**
     * 新增保存字典数据信息
     *
     * @param data 字典数据信息
     * @return 结果
     */
    @Override
    public int insertDictData(SysDictData data) {
        int row = this.dictDataMapper.insert(data).intValue();
        if (row > 0) {
            List<SysDictData> dictDatas = this.dictDataMapper.selectList(Wraps.<SysDictData>lbQ(SysDictData.class).eq(SysDictData::getDictType, data.getDictType()));
            DictUtils.setDictCache(data.getDictType(), dictDatas);
        }
        return row;
    }

    /**
     * 修改保存字典数据信息
     *
     * @param data 字典数据信息
     * @return 结果
     */
    @Override
    public int updateDictData(SysDictData data) {
        int row = this.dictDataMapper.updateById(data).intValue();
        if (row > 0) {
            List<SysDictData> dictDatas = this.dictDataMapper.selectList(Wraps.<SysDictData>lbQ(data).eq(SysDictData::getDictType, data.getDictType()));
            DictUtils.setDictCache(data.getDictType(), dictDatas);
        }
        return row;
    }
}
